##############################################################################
#
#    OpenERP, Open Source Management Solution    
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
from osv import fields, osv

class product_product(osv.osv):
    _inherit = "product.product"
    
    _columns = {
        'property_ids' : fields.one2many('product.property', 'product_id', 'Product properties'),
    }

product_product()

class product_property(osv.osv):
    """
    OpenERP Model : product_property
    """
    
    _name = 'product.property'
    _description = "Product property"
    
    _columns = {
        'name':fields.char('Property Name', size=64, required=True, readonly=False),
        'product_id':fields.many2one('product.product','Related Product', required=False, ondelete='cascade'),
        'type':fields.selection([
            ('text','Text'),
            ('integer','Integer'),
            ('float','Float'),
            ('date','Date'),    
            ('time','Time'),    
            ('datetime','Datetime'),
                            
        ],'Type', select=True, readonly=False),

        'datetime': fields.datetime('Date & Time'),
        'integer': fields.integer('Integer'),
        'text':fields.char('Text', size=64, required=False, readonly=False),
        'date': fields.date('Date'),
        'time': fields.time('Time'),
        'float': fields.float('Float', digits=(16, 2))
    }

    def cleanup_vals(self, vals):
        for field in ('datetime', 'integer', 'text', 'date', 'time', 'float'):
            if field in vals:
                if field != vals["type"]:
                    del vals[field]
        return vals

    def create(self, cr, uid, data, context=None):
        if not data["type"]: data["type"] = "text"
        data = self.cleanup_vals(data)
        return super(product_property, self).create(cr, uid, data, context)

    def write(self, cr, uid, ids, vals, context=None):
        if len(ids) > 1:
            res = True
            # must revalidate each record
            for id in ids:
                res = res and self.write(cr, uid, [id], vals, context=context)
            return res
        else:
            rec = self.read(cr, uid, ids, fields=["type"], context=None)
            vals = vals.copy()
            if rec:
                vals["type"] = rec[0]["type"] or "text"
            return super(product_property, self).write(cr, uid, ids, self.cleanup_vals(vals), context=context)

product_property()
